# django-json-schema-editor

Widget for using
[@json-editor/json-editor](https://www.npmjs.com/package/@json-editor/json-editor)
with Django. See [the blogpost for the announcement and a screenshot](https://406.ch/writing/django-json-schema-editor/).
